@@ -99,7 +99,7 @@ static void about_cb(GtkAction* action, AccessxStatusApplet* sapplet)
 		"version", VERSION,
 		"comments", _("Shows the state of AccessX features such as latched modifiers"),
 		"copyright", _("Copyright \xc2\xa9 2003 Sun Microsystems\n"
-		               "Copyright \xc2\xa9 2012-2019 MATE developers"),
+		               "Copyright \xc2\xa9 2012-2020 MATE developers"),
 		"authors", authors,
 		"documenters", documenters,
 		"translator-credits", _("translator-credits"),
@@ -673,7 +673,7 @@ static cairo_surface_t* accessx_status_applet_mousekeys_image(AccessxStatusApple
 
 static void accessx_status_applet_set_state_icon (AccessxStatusApplet* sapplet, ModifierStruct* modifier, GtkStateFlags state)
 {
-	cairo_surface_t* surface;
+	cairo_surface_t* surface = NULL;
 	GtkIconTheme *icon_theme;
 	gint icon_size, icon_scale;
 	gchar *icon_name = NULL;
