@@ -17,6 +17,11 @@ which mate-autogen || {
     exit 1
 }
 
+which yelp-build || {
+    echo "You need to install yelp-tools" 
+    exit 1
+}
+
 REQUIRED_AUTOMAKE_VERSION=1.9
 USE_MATE2_MACROS=1
 USE_COMMON_DOC_BUILD=yes
