@@ -13,7 +13,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  $Id$
  */
@@ -350,6 +350,11 @@ gboolean acpi_process_event(struct acpi_info * acpiinfo)
     buffer=g_string_new(NULL);
     g_io_channel_read_line_string   ( acpiinfo->channel,buffer,&i,&gerror);
 
+    if (gerror != NULL) {
+      g_warning ("%s", gerror->message);
+      g_error_free (gerror);
+    }
+
     gboolean result;
 
     evt = parse_acpi_event(buffer);
