@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  $Id$
  */
@@ -292,9 +292,6 @@ static int acpi_count;
 static int acpiwatch;
 static struct apm_info apminfo;
 
-/* Declared in acpi-linux.c */
-gboolean acpi_linux_read(struct apm_info *apminfo, struct acpi_info *acpiinfo);
-
 static gboolean acpi_callback (GIOChannel * chan, GIOCondition cond, gpointer data)
 {
   if (cond & (G_IO_ERR | G_IO_HUP)) {
