@@ -27,9 +27,6 @@
 
 #include "cpufreq-selector-procfs.h"
 
-static void     cpufreq_selector_procfs_init          (CPUFreqSelectorProcfs      *selector);
-static void     cpufreq_selector_procfs_class_init    (CPUFreqSelectorProcfsClass *klass);
-
 static gboolean cpufreq_selector_procfs_set_frequency (CPUFreqSelector            *selector,
 						       guint                       frequency,
 						       GError                    **error);
@@ -184,7 +181,7 @@ cpufreq_selector_procfs_set_frequency (CPUFreqSelector *selector,
 	}
 
 	if (frequency != sc_max && frequency != sc_min) {
-		if (abs (sc_max - frequency) < abs (frequency - sc_min))
+		if (abs ((int)sc_max - (int)frequency) < abs ((int)frequency - (int)sc_min))
 			freq = sc_max;
 		else
 			freq = sc_min;
