@@ -304,7 +304,7 @@ drive_button_update (gpointer user_data)
     /* if no volume or mount, display general image */
     if (!self->volume && !self->mount)
     {
-        gtk_widget_set_tooltip_text (GTK_WIDGET (self), "nothing to mount");
+        gtk_widget_set_tooltip_text (GTK_WIDGET (self), _("nothing to mount"));
         screen = gtk_widget_get_screen (GTK_WIDGET (self));
         icon_theme = gtk_icon_theme_get_for_screen (screen); //m
         // note - other good icon would be emblem-unreadable
@@ -400,11 +400,14 @@ drive_button_update (gpointer user_data)
         pixels = cairo_image_surface_get_data (tmp_surface);
 
         GdkRGBA color;
+        GSettings *settings;
+        settings = g_settings_new ("org.mate.drivemount");
         gchar *color_string = g_settings_get_string (settings, "drivemount-checkmark-color");
         if (!color_string)
                 color_string = g_strdup ("#00ff00");
         gdk_rgba_parse (&color, color_string);
         g_free (color_string);
+        g_object_unref (settings);
 
         guchar red = color.red*255;
         guchar green = color.green*255;
@@ -615,7 +618,7 @@ open_drive (DriveButton *self, GtkWidget *item)
 						     GTK_BUTTONS_OK,
 						     _("Cannot execute Caja"));
 	if (error)
-	    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), error->message, NULL);
+	    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
 	else
 	    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "Could not find Caja");
 	g_signal_connect (dialog, "response",
