@@ -473,8 +473,6 @@ redraw_graph(MateNetspeedApplet *applet, cairo_t *cr)
 	GtkWidget *da = GTK_WIDGET(applet->drawingarea);
 	GtkStyleContext *stylecontext = gtk_widget_get_style_context (da);
 	GdkWindow *real_window = gtk_widget_get_window (da);
-	GdkRectangle ra;
-	GtkStateType state;
 	GdkPoint in_points[GRAPH_VALUES], out_points[GRAPH_VALUES];
 	PangoLayout *layout;
 	PangoRectangle logical_rect;
@@ -540,11 +538,6 @@ redraw_graph(MateNetspeedApplet *applet, cairo_t *cr)
 	}
 	cairo_stroke (cr);
 
-	/* draw the 2 labels */
-	state = GTK_STATE_NORMAL;
-	ra.x = 0; ra.y = 0;
-	ra.width = w; ra.height = h;
-
 	text = bytes_to_string(max_val, TRUE, applet->show_bits, applet->short_unit);
 	add_markup_fgcolor(&text, "black");
 	layout = gtk_widget_create_pango_layout (da, NULL);
@@ -829,7 +822,7 @@ about_cb(GtkAction *action, gpointer data)
 			       "version", VERSION,
 			       "copyright", _("Copyright \xc2\xa9 2002-2003 Jörgen Scheibengruber\n"
 			                      "Copyright \xc2\xa9 2011-2014 Stefano Karapetsas\n"
-			                      "Copyright \xc2\xa9 2015-2019 MATE developers"),
+			                      "Copyright \xc2\xa9 2015-2020 MATE developers"),
 			       "comments", _("A little applet that displays some information on the traffic on the specified network device"),
 			       "authors", authors,
 			       "documenters", NULL,
