@@ -95,10 +95,8 @@ stickynote_show_popup_menu (GtkWidget *widget, GdkEventButton *event, GtkWidget
 {
 	if (event->type == GDK_BUTTON_PRESS && event->button == 3)
 	{
-		gtk_menu_popup (GTK_MENU (popup_menu),
-				NULL, NULL,
-				NULL, NULL,
-				event->button, event->time);
+		gtk_menu_popup_at_pointer (GTK_MENU (popup_menu),
+		                           (const GdkEvent*) event);
 	}
 
 	return FALSE;
@@ -143,7 +141,6 @@ void properties_apply_color_cb(StickyNote *note)
 	
 	if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(note->w_def_color)))
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
 		GdkRGBA color, font_color;
 
 		gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (note->w_color), &color);
@@ -151,21 +148,6 @@ void properties_apply_color_cb(StickyNote *note)
 
 		color_str = gdk_rgba_to_string (&color);
 		font_color_str = gdk_rgba_to_string (&font_color);
-#else
-		GdkColor color, font_color;
-		
-		gtk_color_button_get_color (GTK_COLOR_BUTTON (note->w_color), &color);
-		gtk_color_button_get_color (GTK_COLOR_BUTTON (note->w_font_color), &font_color);
-
-		color_str = g_strdup_printf ("#%.2x%.2x%.2x",
-		                             color.red   / 256,
-		                             color.green / 256,
-		                             color.blue  / 256);
-		font_color_str = g_strdup_printf ("#%.2x%.2x%.2x",
-		                                  font_color.red   / 256,
-		                                  font_color.green / 256,
-		                                  font_color.blue  / 256);
-#endif
 	}
 	
 	stickynote_set_color (note, color_str, font_color_str, TRUE);
