@@ -133,7 +133,7 @@ timer_callback (TimerApplet *applet)
     }
     else
     {
-        if (applet->active && !applet->pause)
+        if (!applet->pause)
             applet->elapsed += STEP;
 
         duration = g_settings_get_int (applet->settings, DURATION_KEY);
@@ -272,7 +272,7 @@ timer_about_callback (GtkAction *action, TimerApplet *applet)
                           "title", _("About Timer Applet"),
                           "version", VERSION,
                           "copyright", _("Copyright \xc2\xa9 2014 Stefano Karapetsas\n"
-                                         "Copyright \xc2\xa9 2015-2019 MATE developers"),
+                                         "Copyright \xc2\xa9 2015-2020 MATE developers"),
                           "authors", authors,
                           "comments", _("Start a timer and receive a notification when it is finished"),
                           "translator-credits", _("translator-credits"),
